@@ -305,7 +305,7 @@ sub ExtractTextFromFB2File {
   return $Out;
 }
 
-=head2 ExtractTextFromFB2File($FilePath)
+=head2 ExtractTextFromFB3File($FilePath)
 
 Function receives a path to the fb3-file and returns all significant text from the file as a string
 
@@ -390,7 +390,7 @@ sub ExtractTextFromFB3File {
       or do{ $! = 11; Carp::confess "No FB3 body (expecting $BodyName)" };
 
     # Transform it into plain text
-    my $BodyDoc = $XML->load_xml( string => $BodyXML );
+    my $BodyDoc = $XML->load_xml( string => $BodyXML, huge => 1 );
     my $TransformResults = $Stylesheet->transform( $BodyDoc );
     $Result .= $Stylesheet->output_string( $TransformResults );
   }
